summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmfogedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmfogedit.h')
-rw-r--r--kpovmodeler/pmfogedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmfogedit.h b/kpovmodeler/pmfogedit.h
index 3331f167..5dc1d301 100644
--- a/kpovmodeler/pmfogedit.h
+++ b/kpovmodeler/pmfogedit.h
@@ -46,9 +46,9 @@ class PMFogEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMFogEdit with tqparent and name
*/
- PMFogEdit( TQWidget* tqparent, const char* name = 0 );
+ PMFogEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -46,9 +46,9 @@ class PMFogEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMFogEdit with tqparent and name
+ * Creates a PMFogEdit with parent and name
*/